{% load i18n %}

<div class="module" id="status-check-links">
  <h2> {% trans 'Status check links' %} </h2>
  <ul>
    <li><a href="{% url 'periodic-tasks-status' %}">Periodic tasks status</a></li>
  </ul>
</div>
