{% load i18n %}

<div class="module" id="recent-actions-module">
  <h2> {% trans 'Recent actions' %} </h2>
  <h3> {% trans 'My actions' %} </h3>
  {% load log %}
  {% get_admin_log 10 as admin_log for_user user %}
  {% if not admin_log %}
    <p> {% trans 'None available' %} </p>
  {% else %}
    <ul class="actionlist">
      {% for entry in admin_log %}
        <li class="{% if entry.is_addition %}addlink{% endif %}{% if entry.is_change %}changelink{% endif %}{% if entry.is_deletion %}deletelink{% endif %}">
          {% if entry.is_deletion or not entry.get_admin_url %}
            {{entry.object_repr}}
          {% else %}
            <a href="{{ entry.get_admin_url }}"> {{entry.object_repr}} </a>
          {% endif %}
          <br / >
          {% if entry.content_type %}
            <span class = "mini quiet" > {% filter capfirst %}{{ entry.content_type }}{% endfilter %} < /span >
          {% else %}
            <span class = "mini quiet" > {% trans 'Unknown content' %} < /span >
          {% endif %}
        </li>
      {% endfor %}
    </ul >
  {% endif %}
</div>
